==> hlog-0.16-rc1.tar.gz: hlog-0.16-rc1/xlua/xlua_impl.h <==
/*
 * Copyright (c) 2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __XLUA_IMPL_H
#define __XLUA_IMPL_H

#include <lua.h>
#include <lualib.h>
#include <lauxlib.h>

#include <jeffpc/types.h>

#include <hlog/qso.h>
#include <hlog-lua/xlua.h>

/* push various lib tables */
extern void xlua_pushlib_adif(lua_State *state);
extern void xlua_pushlib_index(lua_State *state);

/* get various types */
extern struct qso *xlua_toqso(lua_State *state, int idx);

/* the following consume the passed in reference */
extern void xlua_pushqso(lua_State *state, struct qso *qso, bool ro);
/* the following aren't reference counted */
extern void xlua_pushtime(lua_State *state, struct time *time, bool ro);

/*
 * check that the stack is in a reasonable state [-0,+0,e]
 *
 * - make sure that there is the correct number of arguments
 * - make sure that there is enough room for any pushes
 */
static inline void xlua_checkstack(lua_State *state, int nargs, int npushes)
{
	if (lua_gettop(state) != nargs)
		(void) luaL_error(state, "bad number of arguments "
				  "(expected %d, got %d)", nargs,
				  lua_gettop(state));

	ASSERT3S(lua_checkstack(state, npushes), !=, 0);
}

#endif

==> hlog-0.17.tar.gz: hlog-0.17/xlua/xlua_impl.h <==
/*
 * Copyright (c) 2020-2021 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef __XLUA_IMPL_H
#define __XLUA_IMPL_H

#include <jeffpc/types.h>

#include <hlog/qso.h>
#include <hlog-lua/xlua.h>

/* push various lib tables */
extern void xlua_pushlib_adif(lua_State *L);
extern void xlua_pushlib_index(lua_State *L);
extern void xlua_pushlib_qso(lua_State *L);

/* get various types */
extern struct qso *xlua_toqso(lua_State *L, int idx);

/* the following consume the passed in reference */
extern void xlua_pushnvl(lua_State *L, struct nvlist *nvl, bool ro);
extern void xlua_pushqso(lua_State *L, struct qso *qso, bool ro);
/* the following aren't reference counted */
extern void xlua_pushtime(lua_State *L, struct time *time, bool ro);

/*
 * check that the stack is in a reasonable state [-0,+0,e]
 *
 * - make sure that there is the correct number of arguments
 * - make sure that there is enough room for any pushes
 */
static inline void xlua_checkstack(lua_State *L, int minnargs, int maxnargs,
				   int npushes)
{
	int nargs = lua_gettop(L);

	if ((nargs < minnargs) || (nargs > maxnargs))
		(void) luaL_error(L, "bad number of arguments "
				  "(expected %d..%d, got %d)", minnargs,
				  maxnargs, nargs);

	ASSERT3S(lua_checkstack(L, npushes), !=, 0);
}

#endif
